####################
Promus Documentation
####################

Promus is a remote manager designed to create and manage `git
<http://git-scm.com/>`_ repositories in a remote server without the
need of admin privileges.

Basic Usage
===========

.. toctree::
    :maxdepth: 2

    What is Promus? <promus>
    Installation <installation>
    Getting Started with Promus <start>
